###########################################
#####   Simple Random sampling  (1)  ######
###########################################


cat("\n########################\n")
cat("Simple Random sampling\n")
cat("########################\n")
cat("\n")

#--------------------------------------------------------------
# Abundance and biomass indices by haul
#--------------------------------------------------------------
cat("\n########################\n")
cat("Plot of indices by haul\n")
cat("########################\n")
cat("\n")

source.check <- try(
  source(paste(wd, "/scripts/Bubble_plot_by_haul_indexes.r", sep=""))
  , silent=T)

if ( !is(source.check,"try-error") )  {
  source(paste(wd, "/scripts/Bubble_plot_by_haul_indexes.r", sep=""))
  cat("\nPlot of indices by haul - completed\n")
} else {
  message("\nPlot of indices by haul skipped - (Run Error)\n")
}

#--------------------------------------------------------------
# Abundance and biomass indices per GSA in the timeseries
#--------------------------------------------------------------

cat("\n########################\n")
cat("Time series of indices\n")
cat("########################\n")
cat("\n")
source(paste(wd, "/scripts/Indices_timeseries_(Simple_Random_Sampling).R", sep=""))
cat("Time series of indices - completed\n")
#--------------------------------------------------------------
# Sex ratio per GSA in the timeseries
#--------------------------------------------------------------
cat("\n########################\n")
cat("Sex-ratio time series\n")
cat("########################\n")
cat("\n")

SR_analysis <-tk_messageBox(type="okcancel",message="Do you want to estimate sex-ratio time series?", default="cancel")

if (SR_analysis=="ok"){
  if (sum(merge_TATB$NB_OF_FEMALES + merge_TATB$NB_OF_MALES, na.rm = TRUE)==0) {
    message("Not enough sex data for sex-ratio estimation")
    cat("\nSex-ratio analysis skipped\n")
  } else {
    source(paste(wd, "/scripts/sex_ratio_timeseries_(Simple_Random_Sampling).R", sep=""))
    cat("\nSex-ratio analysis - completed\n")
  }
} else {
  cat("\nSex-ratio analysis skipped\n")
}


#--------------------------------------------------------------
# Abundance indices of spawners in the time series
#--------------------------------------------------------------
cat("\n############################\n")
cat("Spawners' abundance indices\n")
cat("############################\n")
cat("\n")
#------> check the threshold in the file "~/input/maturity_sizes.csv"
df_cutoff <- read.table(paste(wd, "/input/maturity_sizes.csv", sep=""), sep=";", header=T)
if (length(df_cutoff[df_cutoff$species == sspp & df_cutoff$GSA == GSA, "threshold_spawners" ])==0) {
  message("The SPAWNERS' threshold value for the selected species and GSA combination is not present in the 'maturity_sizes.csv' file. Please, compile the table or skip the analysis.")
}

skip_spawners <- FALSE
spaw_analysis <-tk_messageBox(type="okcancel",message="Do you want to estimate the abundance indices' time series for SPAWNERS?", default="cancel")

if (spaw_analysis=="ok"){
  source.check <- try(
    source(paste(wd, "/scripts/Indices_spawners_timeseries_(Simple_Random_Sampling).R", sep=""))
      , silent=T)

  if ( !is(source.check,"try-error") )  {
    source(paste(wd, "/scripts/Indices_spawners_timeseries_(Simple_Random_Sampling).R", sep=""))
    if (skip_spawners){
      cat("\nSpawners' indices analysis skipped\n")
    } else {
      cat("\nSpawners' indices analysis - completed\n")
    }
  } else {
    message("\nSpawners' indices analysis skipped - (Run Error)\n")
  }
}  else {
  cat("\nSpawners' indices analysis skipped\n")
}

#--------------------------------------------------------------
# Abundance indices of recruits in the timeseries
#--------------------------------------------------------------
cat("\n############################\n")
cat("Recruits' abundance indices\n")
cat("############################\n")
cat("\n")
#------> check the threshold in the file "~/input/maturity_sizes.csv"
df_cutoff <- read.table(paste(wd, "/input/maturity_sizes.csv", sep=""), sep=";", header=T)
if (length(df_cutoff[df_cutoff$species == sspp & df_cutoff$GSA == GSA, "threshold_recruits" ])==0) {
  message("The RECRUITS' threshold value for the selected species and GSA combination is not present in the 'maturity_sizes.csv' file. Please, compile the table or skip the analysis.")
}

rec_analysis <-tk_messageBox(type="okcancel",message="Do you want to estimate the abundance indices' time series for RECRUITS?", default="cancel")

if (rec_analysis=="ok"){
  source.check <- try(
    source(paste(wd, "/scripts/Indices_recruits_timeseries_(Simple_Random_Sampling).R", sep=""))
      , silent=T)

  if ( !is(source.check,"try-error") )  {
    source(paste(wd, "/scripts/Indices_recruits_timeseries_(Simple_Random_Sampling).R", sep=""))
      cat("\nRecruits' indices analysis - completed\n")
  } else {
    message("\nRecruits' indices analysis skipped - (Run Error)\n")
  }

} else {
  cat("\nRecruits' indices analysis skipped\n")
}

#--------------------------------------------------------------
# LFD, L.050 & L0.95
#--------------------------------------------------------------
cat("\n############################\n")
cat("LFD, L.050 & L0.95\n")
cat("############################\n")
cat("\n")

LFD_analysis <-tk_messageBox(type="okcancel",message="Do you want to estimate LFD, L0.50 and L.0.95 for the selected species?", default="cancel")

if (LFD_analysis=="ok"){
  source(paste(wd, "/scripts/LFD_by year_(Simple_Random_Sampling).R", sep=""))
  source(paste(wd, "/scripts/L050_L095_SRS.r", sep=""))
  cat("\nLFD & L0.95 analysis - completed\n")
} else {
  cat("\nLFD & L0.95 analysis skipped\n")
}


#--------------------------------------------------------------
# Spearman test of trends on short timeseries
#--------------------------------------------------------------
cat("\n###########################################\n")
cat("Spearman test of trends on short timeseries\n")
cat("###########################################\n")
cat("\n")
if (length(unique(merge_TATB$YEAR)) >= 3) {
  Trend_analysis <-tk_messageBox(type="okcancel",message=paste("There are ",length(unique(merge_TATB$YEAR))," years of data in the time series. Do you want to apply a Spearman test of trends on available data?",sep=""), default="cancel")

  if (Trend_analysis=="ok"){
    source(paste(wd, "/scripts/spearman_SRS.R", sep=""))
    cat("\nSpearman test - completed\n")
  } else {
    cat("\nSpearman test skipped\n")
  }

} else {
  cat("\nSpearman test skipped\n")
}

#--------------------------------------------------------------
# Intersection Union Test
#--------------------------------------------------------------
cat("\n###########################\n")
cat("Intersection Union Test\n")
cat("###########################\n")
cat("\n")

if (length(unique(merge_TATB$YEAR)) >= 5) {
  IUT_analysis <-tk_messageBox(type="okcancel",message=paste("There are ",length(unique(merge_TATB$YEAR))," years of data in the time series. Do you want to apply a IUT test of trends on available data?",sep=""), default="cancel")

  if (IUT_analysis=="ok"){
    lastn=as.numeric(dlgInput("Select the number of last years to be considered in the IUT test", default=5,Sys.info()[""])$res)
    source(paste(wd, "/scripts/IUT_SRS.r", sep=""))
    cat("\nIUT test - completed\n")
  } else {
    cat("\nIUT test skipped\n")
  }

} else {
  cat("\nIUT test skipped\n")
}

#--------------------------------------------------------------
# Abundance indices for statistical squares
# inverse of CV of abundance indices for statistical squares
# Biomass indices for statistical squares
# Mean individual weight for statistical squares
#--------------------------------------------------------------
cat("\n#############################\n")
cat("Spatial analysis on GFCM grid\n")
cat("#############################\n")
cat("\n")

GRID_analysis <-tk_messageBox(type="okcancel",message=paste("Do you want to perform the estimation of indices on the GFCM statistical squares?",sep=""), default="cancel")

if (GRID_analysis=="ok"){
  source(paste(wd, "/scripts/index_by_grid.r", sep=""))
  cat("\nSpatial analysis on GFCM grid completed\n")
} else {
  cat("\nSpatial analysis on GFCM grid skipped\n")
}


#--------------------------------------------------------------
# Sex ratio for statistical squares
#--------------------------------------------------------------
cat("\n#############################\n")
cat("Sex-ratio on GFCM grid\n")
cat("#############################\n")
cat("\n")

#------> select the minimum number of individuals per haul to be considered in the analysis
sexratio_grid_skip <- FALSE
SR_GRID_analysis <-tk_messageBox(type="okcancel",message=paste("Do you want to perform the estimation of sex-ratio on the GFCM statistical squares?",sep=""), default="cancel")

if (SR_GRID_analysis=="ok"){
  threshold <-    as.numeric(dlgInput("Select the minimum number of individuals per haul to be considered in the analysis", default=30,Sys.info()[""])$res)
  source(paste(wd, "/scripts/sex_ratio_by_grid.r", sep=""))
  if (sexratio_grid_skip){
    cat("\nSex-ratio on GFCM grid skipped\n")
  } else {
    cat("\nSex-ratio on GFCM grid - completed\n")
  }
} else {
  cat("\nSex-ratio on GFCM grid skipped\n")
}

#--------------------------------------------------------------
# Bubble plots - indices of recruits (abundance)
# Bubble plots - indices of spawners (abundance)
#--------------------------------------------------------------
cat("\n################################################\n")
cat("Bubble plots - indices of recruits and spawners\n")
cat("################################################\n")
cat("\n")
#------> check the threshold in the file "~/input/maturity_sizes.csv"
df_cutoff <- read.table(paste(wd, "/input/maturity_sizes.csv", sep=""), sep=";", header=T)
if (length(df_cutoff[df_cutoff$species == sspp & df_cutoff$GSA == GSA, "threshold_spawners" ])==0) {
  message("No threshold value for the selected species and GSA combination in the 'maturity_sizes.csv' file. Please, compile the table or skip the analysis.")
} else if (any(is.na(df_cutoff[df_cutoff$species == sspp & df_cutoff$GSA == GSA, c("threshold_recruits","threshold_spawners") ]))) {
  message("Missing threshold value for the selected species and GSA combination in the 'maturity_sizes.csv' file. Please, compile the table or skip the analysis.")
}

plor_RS_analysis <-tk_messageBox(type="okcancel",message="Do you want to plot abundance indices' by hauls for both RECRUITS and SPAWNERS?", default="cancel")

if (plor_RS_analysis=="ok"){
  # #------> select the dimension of the buffer area around the hauls (metres)
  # buffer <- as.numeric(dlgInput("Select size of the buffer (in meter) to be included in the plot around the hauls' extension ", default=5000,Sys.info()[""])$res)


    verbose <- TRUE
    source(paste(wd, "/scripts/Bubble_plot_by_haul.r", sep=""))
    cat("\nBubble plots - indices of recruits and spawners - completed\n")


}  else {
  cat("\nBubble plots - indices of recruits and spawners skipped\n")
}
