#script for running method of detecting non-linear changes in indicator
#time series using first and second derivatives in an intersect-union test following Casella & Berger chapter 8
#full description in: Trenkel and Rochet in press Intersection-union tests for characterising recent changes in smoothed
# indicator time series. Ecological Indicators
#
#test level alpha for each sub-test;
#author Verena Trenkel, Ifremer
#19/8/2008;
#adapted 12/10/2008 for Trend analyses of ecosystem indicators in Image project

###BEGINNING OF PART THAT HAS TO BE ADAPTED BY USER##########
#for keeping detailed results on first and second derivatives, year with minimum etc write=TRUE
# otherwise write=FALSE
write=FALSE

###Parameters for intersect-union test ############################
alpha=0.05   		#level for each test
CVindicators=0.05 	#0.03 CV for indicator estimates, used in bootstrap for uncertainty
# lastn=5			#number of years to be considered in test, eg 2004-2008 for time series spanning 1980-2008

#change absolute path name or make it a relative path name
source(paste(wd,"/scripts/FunctionsIntersectUnionTestRecentChange.R", sep=""))

#path and filename for data (relative to directory set above)
system<-paste("GSA", GSA, sep="")

#####END PART THAT HAS TO BE ADAPTED BY USER##########


##MAIN part for carrying out analysis###########

 #read data table
 # dat<-read.table(datafile,header=T,sep=";",as.is=T)
df1 <- read.table(paste(wd,"/output/",sspp,"_GSA",GSA,"_(abundance)-Random_Penalized_Sampling_",depth_range[1],"-",depth_range[2]," m_Timeseries.csv", sep=""), sep=";", header=T)
df2 <- read.table(paste(wd,"/output/",sspp,"_GSA",GSA,"_(biomass)-Random_Penalized_Sampling_",depth_range[1],"-",depth_range[2]," m_Timeseries.csv", sep=""), sep=";", header=T)
dat <- data.frame(year = df1$year , ecosystem = paste("GSA",GSA, sep=""), abundance = df1$abundance, biomass = df2$biomass)
response <- c("Abundance (n/km^2)", "Biomass (kg/km^2)")
  cols_1_2 <- c("year", "ecosystem")

  dat[,3] <- dat[,3]
  dat[,4] <- dat[,4]
indicators= colnames(dat)[!(colnames(dat) %in% cols_1_2)]  # c("ARITANT")
indiname=indicators


 #col.names(dat)=c("Year","ecosystem","delta_10","L95_10","10ARISFOLF2D","10PAPE LONF2D","10PAPE LONM2D","10ARISFOLM 2D","10NEPRNORM2D")
 nrows <- length(indicators)/2
 ncols <- 2

 windows(width=(10),height=(5*nrows))
 par(mfrow=c(nrows,ncols),mar=c(5,5,1.5,0.5),las=1,lab=c(5,3,5))


 #for each indicator run test and store results
 #results matrix
 Res<-matrix(NA,nrow=length(indicators),ncol=14)
 dimnames(Res)<-list(NULL,c("Area","Indicator","Indicators","pchisq","RecentDecrease","ChangePointDec",
                            "RecentIncrease","ChangePointInc","RecentLinear","Plinear","DecMK","IncMK","PMKdec","PMKinc"))
 hasdata=0
 j=2
 for(j in 1:length(indicators)){
   lastligne=ifelse(j==length(indicators),TRUE,FALSE)
   indi=dat[,colnames(dat)==indicators[j]]
   id=!is.na(indi)# &dat[,1]<2006
   indi=indi[id]
   years<-dat[id,1]
   Res[j,1]<-system
   Res[j,2:3]<-indicators[j]
   lab_y <- response[j]
   if(length(indi)>=lastn){
     Res[j,2:14]<-unlist(ChangeYears.func(Year=years,Indic=indi,Sd=rep(NA,length(indi)),
                                          species=system,ytext=indicators[j],CV=CVindicators,lastn=lastn,write=write,
                                          speciesname=indiname[j],alpha=alpha,lastligne=lastligne))
     hasdata=1
   }
 }
 write.table(Res,paste(wd,"/output/",system,"IUtest",lastn,"_RPS.csv",sep=""),sep=";",quote=F,row.names=F,app=F)
 if(hasdata==1)savePlot(paste(wd,"/output/",sspp,"_",system,"_SmoothedIndicators_RPS.jpg",sep=""),type="jpg")

 #summarise results across indicators########

 ni=length(indicators)
 res=matrix(NA,nrow=ni*length(system),ncol=14)
 i=1
 for(i in 1:length(system)){
   res[((i-1)*ni+1):(i*ni),1:14]=as.matrix(read.table(paste(wd,"/output/",system[i],"IUtest",lastn,"_RPS.csv",sep=""),sep=";",header=T))
 }
 header=names(read.table(paste(wd,"/output/",system[1],"IUtest",lastn,"_RPS.csv",sep=""),sep=";",header=T))

 dimnames(res)=dimnames(res)=list(NULL,header)
 res=data.frame(res[,c(1,3,4,5,7)])
 res[,4] <- as.factor(res[,4])
 res[,5] <- as.factor(res[,5])

 j=3
 for(j in 4:5) {res[,j]=as.numeric(levels(res[,j])[res[,j]])}
 res$Change=res$RecentDecrease+res$RecentIncrease

 #create table with results, one column per indicator, one row per ecosystem
 indi=sort(unique(res[,2]))
 table=data.frame(cbind(res[res[,2]==indi[1],6],res[res[,2]==indi[2],6]))
 names(table)=indi

 table$system=res[res[,2]==indi[1],1]
 table=table[,c(3,1:2)]

 #replace -1 by - 1 by + and 0 by ""
   for (c in 2:3){
     if (table[c] == -1){table[c] = "decrease"}
     if (table[c] == 1){table[c] = "increase"}
     if (table[c] == 0){table[c] = "nochange"}

 }

 write.table(table,paste(wd, "/output/",sspp,"_GSA",GSA,"_IUT_results_",lastn,"years_RPS.csv",sep=""),sep=";",col.names=T,row.names=F,quote=F)
