merge_TATB <- read.table(paste(wd, "/output/mergeTATB_",GENERE, SPECIE,".csv", sep=""), sep=";",header = T)
strata_scheme <- read.table(paste(wd, "/scripts/utilities/strata.csv", sep=""), sep=";",header = T)
strata_scheme <- strata_scheme[strata_scheme$GSA == unique(merge_TATB$GSA) & strata_scheme$COUNTRY == as.character(unique(merge_TATB$COUNTRY)), ]

# merge_TATB[c(4,5,6,7),] <- merge_TATB[c(1),]
# merge_TATB$N_km2 <- c(22,34,43,21,45,32,12)
# merge_TATB$kg_km2 <- c(0.11,0.34,0.43,0.21,0.45,0.32,0.12)

#-----------------------
# Abundance INDICES
#-----------------------

#------------------------
# Variable definitions #
dependent <- "abundance"
dep_text <-expression(paste("Abundance ", (n/km^2), sep=" "))
varcol <- which(colnames(merge_TATB)=="N_km2")
col_response <- which(colnames(merge_TATB)=="N_km2")
positive_hauls<- 0
total_hauls<- 0

GENERE <- as.character(unique(merge_TATB$GENUS)[unique(merge_TATB$GENUS) != -1])
SPECIE <- as.character(unique(merge_TATB$SPECIES)[unique(merge_TATB$SPECIES) != -1])
sspp <- paste(GENERE,SPECIE, sep="")
GSA <- unique(merge_TATB$GSA)
species <- sspp
#------------------------

#------------------------------------------
# plotting species' depth range information
g1 <- ggplot(merge_TATB[merge_TATB[,varcol] >0,], aes(x=MEAN_DEPTH)) + geom_density()+xlab("depth (m)")+ggtitle(paste(sspp, " - GSA",GSA,sep="" ))
ggsave(paste(wd,"/output/depth.distribution_",sspp,"_GSA",GSA,".jpg", sep=""),width=5, height=5)
g2 <- ggplot(merge_TATB[merge_TATB[,varcol]>0,], aes(x=species, y=MEAN_DEPTH)) + geom_boxplot() + xlab("") + ylim(0, max(merge_TATB$MEAN_DEPTH))+ylab("depth (m)")+ggtitle(paste(sspp, " - GSA",GSA,sep="" ))
ggsave(paste(wd,"/output/depth.distribution_(boxplot)",sspp,"_GSA",GSA,".jpg", sep=""),width=5, height=5)
grid.arrange(g1, g2, ncol=2)
#------------------------------------------

ddd <- merge_TATB
year_range <- data.frame(year = sort(unique(merge_TATB$YEAR)))

res_table_cala2 <- data.frame(year=sort(unique(merge_TATB$YEAR)))
res_table_cala2$abundance <- NA
res_table_cala2$sd <- NA
res_table_cala2$CV <- NA
res_table_cala2$incCV <- NA
res_table_cala2$positive_hauls_perc <- NA

i=1
for(i in 1:length(res_table_cala2[,1])) {

  data2 <- ddd[ddd$YEAR == res_table_cala2[i,1] , ]
  if (length(data2[data2$TOTAL_NUMBER_IN_THE_HAUL >0 ,"TOTAL_NUMBER_IN_THE_HAUL"])>=1){

  res_table_cala2[i,2] <- mean(data2$N_km2)
  res_table_cala2[i,3] <- sd(data2$N_km2)
  res_table_cala2[i,4] <- res_table_cala2[i,3]/res_table_cala2[i,2]
  res_table_cala2[i,5] <- 1/res_table_cala2[i,4]
  } else {
    res_table_cala2[i,2] <- 0
    res_table_cala2[i,3] <- NA
    res_table_cala2[i,4] <- NA
    res_table_cala2[i,5] <- NA
    }

  positive_hauls[i] <- length(merge_TATB[merge_TATB$TOTAL_NUMBER_IN_THE_HAUL>0 & merge_TATB$YEAR == res_table_cala2[i,1],"TOTAL_NUMBER_IN_THE_HAUL"])
  total_hauls[i] <- length(merge_TATB[merge_TATB$YEAR == res_table_cala2[i,1],"HAUL_NUMBER"])

  res_table_cala2[i,6] <- positive_hauls[i]/total_hauls[i]*100

  }

timeseries <- res_table_cala2
abundance_TS <- res_table_cala2
# plot timeseries of mean indices
    main <- paste(sspp,"_GSA",GSA,"_(",dependent,")-Simple_Random_Sampling_", sep="")
    main.lab <- paste(sspp," GSA",GSA," (",dependent,")-SRS ", sep="")
    max_index <- max(timeseries[,2])  + (max(timeseries[!is.na(timeseries$sd),"sd"])*1.2)
    write.table(timeseries, paste(wd,"/output/",main,"_Timeseries.csv", sep=""), sep=";", row.names = F)


    tiff(paste(wd,"/output/",main,"_Timeseries.tiff",sep=""), res = 300, width = 8, height = 7, units = 'in', compression = 'lzw', pointsize = 1/300)
    par(mfrow=c(1,1),oma=c(1,1,1,1), mgp=c(2, 1,0))
    plot(timeseries[,1],  timeseries[,2], type="b", col="black", pch=16, xlab="year", ylim=c(0,max_index*1.2), ylab=dep_text, main=main.lab) # ylim=c(0,max_index*1.2)
    lines(timeseries[,1], (timeseries[,2]-1.96*timeseries[,3]), type="l",lty=2, col="red" )
    lines(timeseries[,1], (timeseries[,2]+1.96*timeseries[,3]), type="l",lty=2, col="red" )
    legend("topright", c("time series", "CI"), lty=c(1,1), pch=c(16, NA), col=c("black","red"))
    dev.off()

# plot timeseries of inverse of CV
    main <- paste(sspp,"_GSA",GSA,"_(inverseCV of abundance)-Simple_Random_Sampling_", sep="")
    main.lab <- paste(sspp," GSA",GSA," (1/CV of mean abundance)-SRS ", sep="")
    max_index <- max(timeseries[,5])


    tiff(paste(wd,"/output/",main,"_Timeseries.tiff",sep=""), res = 300, width = 8, height = 7, units = 'in', compression = 'lzw', pointsize = 1/300)
    par(mfrow=c(1,1),oma=c(1,1,1,1), mgp=c(2, 1,0))
    plot(timeseries[,1],  timeseries[,5], type="b", col="black", pch=16, xlab="year", ylim=c(0,max_index*1.2), ylab="1/CV", main=main.lab) # ylim=c(0,max_index*1.2)
    legend("topright", c("inverse CV"), lty=c(1), pch=c(16), col=c("black"))
    dev.off()
# plot number of positive hauls per year
    main <- paste(sspp,"_GSA",GSA,"_(positive hauls)-Simple_Random_Sampling_", sep="")
    main.lab <- paste(sspp," GSA",GSA," (positive hauls %)-SRS ", sep="")
    max_index <- max(timeseries[,6])

    tiff(paste(wd,"/output/",main,"_Timeseries.tiff",sep=""), res = 300, width = 8, height = 7, units = 'in', compression = 'lzw', pointsize = 1/300)
    par(mfrow=c(1,1),oma=c(1,1,1,1), mgp=c(2, 1,0))
    plot(timeseries[,1],  timeseries[,6], type="b", col="black", pch=16, xlab="year", ylim=c(0,max_index*1.2), ylab="number of hauls (%)", main=main.lab) # ylim=c(0,max_index*1.2)
    legend("topright", c("number of positive hauls %"), lty=c(1), pch=c(16), col=c("black"))
    dev.off()

    cat("\n Estimation of abundance indices completed \n")

source(paste(wd, "/scripts/Indices_timeseries_(Simple_Random_Sampling)_F.R", sep=""))
source(paste(wd, "/scripts/Indices_timeseries_(Simple_Random_Sampling)_M.R", sep=""))

#-----------------------
# BIOMASS INDICES
#-----------------------

    #------------------------
    # Variable definitions #
    dependent <- "biomass"
    dep_text <-expression(paste("Biomass ", (kg/km^2), sep=" "))
    varcol <- which(colnames(merge_TATB)=="kg_km2")
    col_response <- which(colnames(merge_TATB)=="kg_km2")
    GENERE <- as.character(unique(merge_TATB$GENUS)[unique(merge_TATB$GENUS) != -1])
    SPECIE <- as.character(unique(merge_TATB$SPECIES)[unique(merge_TATB$SPECIES) != -1])
    sspp <- paste(GENERE,SPECIE, sep="")
    GSA <- unique(merge_TATB$GSA)
    species <- sspp
    #------------------------

    ddd <- merge_TATB
    year_range <- data.frame(year = sort(unique(merge_TATB$YEAR)))

    res_table_cala2 <- data.frame(year=sort(unique(merge_TATB$YEAR)))
    res_table_cala2$biomass <- NA
    res_table_cala2$sd <- NA
    res_table_cala2$CV <- NA
    res_table_cala2$incCV <- NA
    res_table_cala2$positive_hauls_perc <- NA



    i=1
    for(i in 1:length(res_table_cala2[,1])) {

      data2 <- ddd[ddd$YEAR == res_table_cala2[i,1] , ]
      if (length(data2[data2$TOTAL_NUMBER_IN_THE_HAUL >0 ,"TOTAL_NUMBER_IN_THE_HAUL"])>=1){

        res_table_cala2[i,2] <- mean(data2$kg_km2)
        res_table_cala2[i,3] <- sd(data2$kg_km2)
        res_table_cala2[i,4] <- res_table_cala2[i,3]/res_table_cala2[i,2]
        res_table_cala2[i,5] <- 1/res_table_cala2[i,4]
      } else {
        res_table_cala2[i,2] <- 0
        res_table_cala2[i,3] <- NA
        res_table_cala2[i,4] <- NA
        res_table_cala2[i,5] <- NA
      }

      positive_hauls[i] <- length(merge_TATB[merge_TATB$TOTAL_NUMBER_IN_THE_HAUL>0 & merge_TATB$YEAR == res_table_cala2[i,1],"TOTAL_NUMBER_IN_THE_HAUL"])
      total_hauls[i] <- length(merge_TATB[merge_TATB$YEAR == res_table_cala2[i,1],"HAUL_NUMBER"])

      res_table_cala2[i,6] <- positive_hauls[i]/total_hauls[i]*100

    }

    timeseries <- res_table_cala2
    biomass_TS <- res_table_cala2

# plot timeseries of mean indices
    main <- paste(sspp,"_GSA",GSA,"_(",dependent,")-Simple_Random_Sampling_", sep="")
    main.lab <- paste(sspp," GSA",GSA," (",dependent,")-SRS ", sep="")
    max_index <- max(timeseries[,2])  + (max(timeseries[!is.na(timeseries$sd),"sd"])*1.2)
    write.table(timeseries, paste(wd,"/output/",main,"_Timeseries.csv", sep=""), sep=";", row.names = F)

    tiff(paste(wd,"/output/",main,"_Timeseries.tiff",sep=""), res = 300, width = 8, height = 7, units = 'in', compression = 'lzw', pointsize = 1/300)
    par(mfrow=c(1,1),oma=c(1,1,1,1), mgp=c(2, 1,0))
    plot(timeseries[,1],  timeseries[,2], type="b", col="black", pch=16, xlab="year", ylim=c(0,max_index*1.2), ylab=dep_text, main=main.lab) # ylim=c(0,max_index*1.2)
    lines(timeseries[,1], (timeseries[,2]-1.96*timeseries[,3]), type="l",lty=2, col="red" )
    lines(timeseries[,1], (timeseries[,2]+1.96*timeseries[,3]), type="l",lty=2, col="red" )
    legend("topright", c("time series", "CI"), lty=c(1,2), pch=c(16, NA), col=c("black","red"))
    dev.off()


# # plot timeseries of inverse of CV
#     main <- paste(sspp,"_GSA",GSA,"_(inverseCV of biomass)_",depth_range[1],"-",depth_range[2], " m", sep="")
#     main.lab <- paste(sspp," GSA",GSA," (1/CV of mean biomass) ",depth_range[1],"-",depth_range[2], " m", sep="")
#     max_index <- max(timeseries[,5])
#
#     tiff(paste(wd,"/output/",main,"_Timeseries.tiff",sep=""), res = 300, width = 8, height = 7, units = 'in', compression = 'lzw', pointsize = 1/300)
#     par(mfrow=c(1,1),oma=c(1,1,1,1), mgp=c(2, 1,0))
#     plot(timeseries[,1],  timeseries[,5], type="b", col="black", pch=16, xlab="year", ylim=c(0,max_index*1.2), ylab="1/CV", main=main.lab) # ylim=c(0,max_index*1.2)
#     legend("topright", c("inverse CV"), lty=c(1), pch=c(16), col=c("black"))
#     dev.off()

cat("\n Estimation of biomass indices completed \n")

source(paste(wd, "/scripts/MIW-Simple_Random_Sampling.r", sep=""))


